pub struct WidthBoundsConfig {
pub min: Option<u16>,
pub max: Option<u16>,
}Expand description
Width-bounds override. Either side may be omitted; a missing side inherits from the segment’s built-in default.
Fields
min: Option<u16>max: Option<u16>Trait Implementations
Sourceimpl Clone for WidthBoundsConfig
impl Clone for WidthBoundsConfig
Sourcefn clone(&self) -> WidthBoundsConfig
fn clone(&self) -> WidthBoundsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WidthBoundsConfig
impl Debug for WidthBoundsConfig
Sourceimpl Default for WidthBoundsConfig
impl Default for WidthBoundsConfig
Sourcefn default() -> WidthBoundsConfig
fn default() -> WidthBoundsConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WidthBoundsConfig
impl<'de> Deserialize<'de> for WidthBoundsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WidthBoundsConfig
impl JsonSchema for WidthBoundsConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for WidthBoundsConfig
impl PartialEq for WidthBoundsConfig
Sourcefn eq(&self, other: &WidthBoundsConfig) -> bool
fn eq(&self, other: &WidthBoundsConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for WidthBoundsConfig
impl Eq for WidthBoundsConfig
impl StructuralPartialEq for WidthBoundsConfig