RepoKind

Enum RepoKind 

#[non_exhaustive]
pub enum RepoKind { Main, LinkedWorktree { name: String, }, Bare, Submodule, }
Which flavor of repository gix::discover found.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Main

A regular checkout with a .git/ directory.



LinkedWorktree

A linked worktree (.git is a file with gitdir: ...). name is the per-worktree directory basename (.git/worktrees/<name>/).

Fields

name: String


Bare

A bare repository. git_branch hides on this kind (no working tree means no dirty state).



Submodule

A submodule checkout. Has a working tree and HEAD like Main, but carried as a distinct variant so segments that want to style submodules differently don’t re-classify.