sgr_open

Function sgr_open 

pub fn sgr_open(style: &Style, theme: &Theme, cap: Capability) -> String
Emit the ANSI SGR prefix for style under cap. Returns an empty string when the style is plain or the capability is None with no decorations.