extra_usage segment: monthly overage credits. Auto-hides when
the account has not enabled overage (is_enabled = false); surfaces
error strings for fetch failures per spec Render semantics.
extra_usage segment: monthly overage credits. Auto-hides when
the account has not enabled overage (is_enabled = false); surfaces
error strings for fetch failures per spec Render semantics.