pub fn sgr_open(style: &Style, theme: &Theme, cap: Capability) -> StringExpand description
Emit the ANSI SGR prefix for style under cap. Returns an empty
string when the style is plain or the capability is None with no
decorations.
pub fn sgr_open(style: &Style, theme: &Theme, cap: Capability) -> StringEmit the ANSI SGR prefix for style under cap. Returns an empty
string when the style is plain or the capability is None with no
decorations.